CacheEventScope

Enum CacheEventScope 

pub enum CacheEventScope {
    Key {
        key: CacheKey<'static>,
    },
    Tag {
        tag: String,
        affected_keys: u64,
    },
    Cache {
        affected_keys: Option<u64>,
    },
}
Logical scope affected by a cache event.

Variants



Key

Event for one cache key.

Fields

key: CacheKey<'static>

Physical cache key.



Tag

Event for one invalidation tag.

Fields

tag: String

Invalidated tag.

affected_keys: u64

Number of keys affected by the operation.



Cache

Event for the whole cache.

Fields

affected_keys: Option<u64>

Approximate number of keys affected, when known.

Implementations

Source

impl CacheEventScope

pub fn key(&self) -> Option<&str>

Return the event key when this is a key-scoped event.

pub fn tag(&self) -> Option<&str>

Return the event tag when this is a tag-scoped event.

pub fn affected_keys(&self) -> Option<u64>

Return the affected-key count when the scope carries one.