pub struct CacheEventOptions { /* private fields */ }Expand description
Subscription filters for cache events.
Filters are intentionally metadata-only. They are cheap enough to apply in the subscriber wrapper and avoid coupling event publication to decoded values.
Implementations
Sourceimpl CacheEventOptions
impl CacheEventOptions
Sourcepub fn include_kind(self, kind: CacheEventKind) -> Self
pub fn include_kind(self, kind: CacheEventKind) -> Self
Include one event kind.
Sourcepub fn include_kinds<I>(self, kinds: I) -> Selfwhere
I: IntoIterator<Item = CacheEventKind>,
pub fn include_kinds<I>(self, kinds: I) -> Selfwhere
I: IntoIterator<Item = CacheEventKind>,
Include several event kinds.
Sourcepub fn exclude_kind(self, kind: CacheEventKind) -> Self
pub fn exclude_kind(self, kind: CacheEventKind) -> Self
Exclude one event kind.
Sourcepub fn exclude_kinds<I>(self, kinds: I) -> Selfwhere
I: IntoIterator<Item = CacheEventKind>,
pub fn exclude_kinds<I>(self, kinds: I) -> Selfwhere
I: IntoIterator<Item = CacheEventKind>,
Exclude several event kinds.
Sourcepub fn key_prefix(self, key_prefix: impl Into<String>) -> Self
pub fn key_prefix(self, key_prefix: impl Into<String>) -> Self
Restrict events to key-scoped events whose key starts with the prefix.
Sourcepub fn origin(self, origin: CacheEventOrigin) -> Self
pub fn origin(self, origin: CacheEventOrigin) -> Self
Restrict events to one origin.
Sourcepub fn value_mode(self, value_mode: CacheEventValueMode) -> Self
pub fn value_mode(self, value_mode: CacheEventValueMode) -> Self
Set the value mode requested by this subscription.
Sourcepub fn value_mode_value(&self) -> CacheEventValueMode
pub fn value_mode_value(&self) -> CacheEventValueMode
Return the requested value mode.
Sourcepub fn matches(&self, event: &CacheEvent) -> bool
pub fn matches(&self, event: &CacheEvent) -> bool
Return whether this event passes all filters.