CacheEventOptions

Struct CacheEventOptions 

pub struct CacheEventOptions { /* private fields */ }
Subscription filters for cache events.

Filters are intentionally metadata-only. They are cheap enough to apply in the subscriber wrapper and avoid coupling event publication to decoded values.

Implementations

Source

impl CacheEventOptions

pub fn new() -> Self

Create event options that accept all published events.

pub fn mutations() -> Self

Create event options for mutation/invalidation events.

pub fn access() -> Self

Create event options for high-volume access/load events.

pub fn include_kind(self, kind: CacheEventKind) -> Self

Include one event kind.

pub fn include_kinds<I>(self, kinds: I) -> Self
where I: IntoIterator<Item = CacheEventKind>,

Include several event kinds.

pub fn exclude_kind(self, kind: CacheEventKind) -> Self

Exclude one event kind.

pub fn exclude_kinds<I>(self, kinds: I) -> Self
where I: IntoIterator<Item = CacheEventKind>,

Exclude several event kinds.

pub fn key(self, key: impl Into<String>) -> Self

Restrict events to one exact key.

pub fn key_prefix(self, key_prefix: impl Into<String>) -> Self

Restrict events to key-scoped events whose key starts with the prefix.

pub fn tag(self, tag: impl Into<String>) -> Self

Restrict events to a tag.

pub fn origin(self, origin: CacheEventOrigin) -> Self

Restrict events to one origin.

pub fn value_mode(self, value_mode: CacheEventValueMode) -> Self

Set the value mode requested by this subscription.

pub fn value_mode_value(&self) -> CacheEventValueMode

Return the requested value mode.

pub fn matches(&self, event: &CacheEvent) -> bool

Return whether this event passes all filters.